@@ -10,12 +10,14 @@ use args::Opt;
 use changelog::Changelog;
 use git_cliff_core::commit::Commit;
 use git_cliff_core::config::Config;
+use git_cliff_core::embed::EmbeddedConfig;
 use git_cliff_core::error::{
 	Error,
 	Result,
 };
 use git_cliff_core::release::Release;
 use git_cliff_core::repo::Repository;
+use git_cliff_core::DEFAULT_CONFIG;
 use std::env;
 use std::fs::{
 	self,
@@ -25,6 +27,13 @@ use std::io;
 
 /// Runs `git-cliff`.
 pub fn run(mut args: Opt) -> Result<()> {
+	// Create the configuration file if init flag is given.
+	if args.init {
+		info!("Saving the configuration file to {:?}", DEFAULT_CONFIG);
+		fs::write(DEFAULT_CONFIG, EmbeddedConfig::get_config()?)?;
+		return Ok(());
+	}
+
 	// Set the working directory.
 	if let Some(workdir) = args.workdir {
 		args.config = workdir.join(args.config);
@@ -37,14 +46,30 @@ pub fn run(mut args: Opt) -> Result<()> {
 		}
 	}
 
-	// Parse configuration file.
-	let mut config = Config::parse(match args.config.to_str() {
+	// Parse the configuration file.
+	let mut path = match args.config.to_str() {
 		Some(v) => Ok(v.to_string()),
 		None => Err(Error::IoError(io::Error::new(
 			io::ErrorKind::Other,
 			"path contains invalid characters",
 		))),
-	}?)?;
+	}?;
+	if let Some(config_path) = dirs_next::config_dir()
+		.map(|dir| dir.join(env!("CARGO_PKG_NAME")).join(DEFAULT_CONFIG))
+		.map(|path| path.to_str().map(String::from))
+		.flatten()
+	{
+		if fs::metadata(&config_path).is_ok() {
+			path = config_path;
+		}
+	}
+
+	let mut config = if fs::metadata(&path).is_ok() {
+		Config::parse(path)?
+	} else {
+		warn!("{:?} is not found, using the default configuration.", path);
+		EmbeddedConfig::parse()?
+	};
 
 	// Update the configuration based on command line arguments.
 	match args.strip.as_deref() {
@@ -88,7 +113,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 	} else if args.latest {
 		if tags.len() < 2 {
 			return Err(Error::ChangelogError(String::from(
-				"latest tag cannot be processed",
+				"Latest tag cannot be processed",
 			)));
 		} else if let (Some(tag1), Some(tag2)) = (
 			tags.get_index(tags.len() - 2).map(|(k, _)| k),
